
#include <avr/io.h>
#include "common.h"
#include "led.h"

/*---------------------------------------------------------------------
  ledSelectDigit(...)

  Selects a digit of the led display. Ports PB0..PB2 drive each
  digit of the LED display, where PB2 drives the high order digit and
  PB0 drives the low order digit.

  Input: a single numeric digit, range 0..2. 0 drives the high order
         digit, 2 drives the low order digit. To turn off all digits,
         pass a number > 2.
---------------------------------------------------------------------*/
void ledSelectDigit( char cDigit )
{

  switch ( cDigit )
  {
    case 0:
      clear_bit( PORTB, PB2 );
      break;
    case 1:
      clear_bit( PORTB, PB1 );
      clear_bit( PORTD, PD4 );		// DP on
      break;
    case 2:
      clear_bit( PORTB, PB0 );
      break;
    case NO_DIGIT:
      set_bit( PORTB, PB0 );
      set_bit( PORTB, PB1 );
      set_bit( PORTB, PB2 );
      set_bit( PORTD, PD4 );		// DP off
  }
}

/*---------------------------------------------------------------------
  ledOutputNumber(...)

  Outputs a number to the led display. Ports PD0..PD3 are connected
  to the A-B-C-D inputs of a 74LS47 which decodes the number and
  activates the corresponding segments of the bank of LEDs. 

  This circuit got a little mixed up:
  A is driven by PD3
  B is driven by PD0
  C is driven by PD1
  D is driven by PD2

  Input: a single numeric digit, range 0..9 (ascii or binary, only the
         low-order nibble is processed.)
---------------------------------------------------------------------*/
void ledOutputNumber( char cNumber )
{
  // Output the digit as BCD on PD0..PD3

  if ( test_bit( cNumber, 0 ) )
    set_bit( PORTD, PD3 );
  else
    clear_bit( PORTD, PD3 );

  if ( test_bit( cNumber, 1 ) )
    set_bit( PORTD, PD0 );
  else
    clear_bit( PORTD, PD0 );

  if ( test_bit( cNumber, 2 ) )
    set_bit( PORTD, PD1 );
  else
    clear_bit( PORTD, PD1 );

  if ( test_bit( cNumber, 3 ) )
    set_bit( PORTD, PD2 );
  else
    clear_bit( PORTD, PD2 );
}
